@@ -10,6 +10,7 @@
 #' \item ranef
 #' \item vcovHC
 #' \item nobs
+#' \item maxLik
 #' }
 #' 
 #' 
@@ -54,6 +55,12 @@ NULL
 #' @export
 NULL
 
+#' @rdname re-export_functions
+#' @name maxLik
+#' @importFrom maxLik maxLik
+#' @export
+NULL
+
 
 #' plm package: linear models for panel data
 #' 
